@@ -1,5 +1,7 @@
 use utf8;
 use strict;
+use warnings;
+no warnings qw(uninitialized);
 
 #=======================================================
 package XML::Pastor::Generator;
@@ -72,8 +74,8 @@ sub _generateSingle {
 	my $args	= {@_};
 	my $model	= $args->{model};
 	my $mode	= $args->{mode};
-	my $module	= $args->{module};
-	my $class_prefix = $args->{class_prefix};	
+	my $class_prefix = $args->{class_prefix};
+	my $module	= $args->{module} || $class_prefix;		
 	my $code	= $self->_fabricatePrelude(@_);	
 	my $destination		= $args->{destination} || '/tmp/lib/perl/';
 	my $verbose	= $self->{verbose} || 0;
@@ -99,7 +101,11 @@ sub _generateSingle {
 	}else { 
 		# generate module
 		$destination .= '/' if ($destination && ($destination !~ /\/$/));
-		$class_prefix .= '::' if ($class_prefix && ($class_prefix !~ /::$/));		
+		$class_prefix .= '::' if ($class_prefix && ($class_prefix !~ /::$/));
+		while ($module =~ /:$/) {
+			$module =~ s/:$//;
+		}		
+				
 		my $file	= $module or  die "Pastor:Generator:_generateSingle:A 'module' name is required!\n"; 
 		
 		$file 		= $destination .  $file . '.pm';	
@@ -113,9 +119,11 @@ sub _generateSingle {
 # Generate a multiple 'modules' of code, one for each class.
 # Then write the code to module files within the 'destination' directory 
 sub _generateMultiple {
-	my $self 	= shift;
-	my $args	= {@_};
-	my $model	= $args->{model};
+	my $self 			= shift;
+	my $args			= {@_};
+	my $model			= $args->{model};
+	my $class_prefix	= $args->{class_prefix}; 	
+	my $module 			= $args->{module} || $class_prefix; 
 	my $types	= $model->type();
 	my $destination		= $args->{destination} || '/tmp/lib/perl/';
 	$destination .= '/' if ($destination && ($destination !~ /\/$/));
@@ -134,9 +142,55 @@ sub _generateMultiple {
 			$self->_writeCode(@_, file=>$file, code=>$code);
 		}
 	}
+
+	if ($module) {
+		# Generate the module with all the 'use' statements for different modules.
+		my $code = $self->_fabricateModuleCode(@_);
+		# get ride of any trailing columns.
+		while ($module =~ /:$/) {
+			$module =~ s/:$//;
+		}		
+		my $file	= $module;
+		$file = $destination . $file . '.pm';
+		$file =~ s/::/\//g;
+				
+		$self->_writeCode(@_, file=>$file, code=>$code);
+	}
+	
 	return $self;		
 }
 
+
+#--------------------------------------------
+# Fabricate the code for the module that will 'use' all the generated classes.
+#--------------------------------------------
+sub _fabricateModuleCode {
+	my $self 			= shift;
+	my $args			= {@_};
+	my $model			= $args->{model};
+	my $class_prefix	= $args->{class_prefix}; 	
+	my $module 			= $args->{module} || $class_prefix; 
+	my $code;
+		
+	# get ride of any trailing columns.
+	while ($module =~ /:$/) {
+		$module =~ s/:$//;
+	}
+	$code  = _fabricatePrelude(@_);
+	$code .= "\npackage $module;\n";
+		
+	foreach my $items ($model->type(), 	$model->element()) {
+		foreach my $name (sort keys %$items) {
+			my $object 	= $items->{$name};
+			my $class	= $object->class();			
+			$code .= "\nuse $class;"
+		}
+	}
+	
+	$code .= "\n\n1;\n";
+	return $code;		
+}
+
 #--------------------------------------------
 # Fabricate the first prelude stub of code for each module.
 # Needed only in the begining of each physical module file.
@@ -144,11 +198,11 @@ sub _fabricatePrelude {
 	my $self 	= shift;
 	my $code = "";
 	
-	$code .= "\n#PASTOR: Code generated by XML::Pastor/" . $XML::Pastor::VERSION . " at '" . localtime() . "'\n";
+	$code .= "\n#PASTOR: Code generated by XML::Pastor/" . XML::Pastor->version() . " at '" . localtime() . "'\n";
 	$code .= "\nuse utf8;";
 	$code .= "\nuse strict;";	
-#	$code .= "\nuse warnings;";
-#	$code .= "\nno warnings qw(uninitialized);";
+	$code .= "\nuse warnings;";
+	$code .= "\nno warnings qw(uninitialized);";
 
 	$code .= "\n\nuse XML::Pastor;\n\n";	
 	return $code;	
@@ -674,7 +728,7 @@ Note that there may be other bugs or limitations that the author is not aware of
 
 =head1 AUTHOR
 
-Ayhan Ulusoy <dev@ulusoy.name>
+Ayhan Ulusoy <dev(at)ulusoy(dot)name>
 
 
 =head1 COPYRIGHT
