@@ -1,6 +1,7 @@
 use utf8;
 use strict;
-
+use warnings;
+no warnings qw(uninitialized);
 
 #=======================================================
 package XML::Pastor::Schema;
