@@ -1,19 +1,23 @@
 use utf8;
 use strict;
+use warnings;
+no warnings qw(uninitialized);
+
+#======================================================================
+package XML::Pastor::Schema::Parser;
 
 use Cwd;
 use File::Spec;
 use LWP::UserAgent;
 use URI;
 use URI::file;
-
+use Class::Accessor;
+use Data::HashArray;
 
 use XML::LibXML;
 use XML::Pastor::Stack;
 use XML::Pastor::Schema;
 
-#======================================================================
-package XML::Pastor::Schema::Parser;
 use XML::Pastor::Util  qw(getAttributeHash sprint_xml_element);
 use Scalar::Util qw(reftype);
 
@@ -83,10 +87,12 @@ sub includeSchema() {
 
 #------------------------------------------------------------
 # Called internally when an 'import' element is encountered in a schema.
-# NOT -YET- SUPPORTED!
 #------------------------------------------------------------
 sub importSchema() {
-	die "Pastor : Schema IMPORT functionality not yet supported!\n";
+	my $self=shift;
+	
+	$self->_process(@_, operation=>"import");		
+#	die "Pastor : Schema IMPORT functionality not yet supported!\n";
 }
 
 #------------------------------------------------------------
@@ -262,12 +268,14 @@ sub _processNode {
 	# If the element name matches any string below, we'll do the corresponding action.
 	SWITCH: for ($name){ 	# iterator = $_ (we'll do pattern matching on it)
 		/^all$/				and do {	last SWITCH;};		
-		/^annotation$/		and return 0;		# ignore children as well
+		/^annotation$/		and do {	last SWITCH;};	
+		/^appinfo$/			and return 0;		# ignore children as well		
 		/^attribute$/		and do { 	$obj=$self->_processAttribute($node);		last SWITCH;};
 		/^attributeGroup$/	and do { 	$obj=$self->_processAttributeGroup($node);	last SWITCH;};
 		/^choice$/			and do {	last SWITCH;};
 		/^complexContent$/	and do {	last SWITCH;};		
 		/^complexType$/		and do {	$obj=$self->_processComplexType($node);		last SWITCH;};
+		/^documentation$/	and do { 	$obj=$self->_processDocumentation($node);	last SWITCH;};	
 		/^element$/			and do {	$obj=$self->_processElement($node);			last SWITCH;};
 		/^extension$/		and do {	$obj=$self->_processExtension($node);		last SWITCH;};		
 		/^enumeration$/		and do {	$obj=$self->_processEnumeration($node);		last SWITCH;};
@@ -283,6 +291,7 @@ sub _processNode {
 		/^schema$/			and do {	$obj=$self->_processSchemaNode($node);		last SWITCH;};
 		/^selector$/		and do {	return 0;};	# ignore children as well	
 		/^sequence$/		and do {	last SWITCH;};
+		/^simpleContent$/	and do {	$obj=$self->_processSimpleContent($node);	last SWITCH;};		
 		/^simpleType$/		and do {	$obj=$self->_processSimpleType($node);		last SWITCH;};
 		/^unique$/			and do {	return 0;};		
 		/^union$/			and do {	$obj=$self->_processUnion($node);		last SWITCH;};		
@@ -303,7 +312,7 @@ sub _processNode {
 	
 	# CLEAN UP
 	if (defined($obj)) {
-		$self->_fixNameSpaces($obj, $node, 'type', 'base', 'ref');
+		$self->_fixNameSpaces($obj, $node, ['type', 'base', 'ref']);
 		
 		# 'Union' must be post-processed
 		if (UNIVERSAL::isa($obj, "XML::Pastor::Schema::Union")) {
@@ -490,6 +499,42 @@ sub _processGroup {
 	return $obj;	
 }
 
+
+#------------------------------------------------------------
+# This routine is called whenever an 'documentation' element is encountered 
+# in the schema being processed.
+#------------------------------------------------------------
+sub _processDocumentation {
+	my $self 	= shift;
+	my $node 	= shift;	
+	my $context = $self->context();			
+	my $attribs	= getAttributeHash($node);
+	my $value	= $attribs->{value};
+	
+	# Find the top-most SimpleType model object closest to the top of the node-stack 
+	# of the current context. This will become our 'host' object.
+	if (my $host=$context->findNode(class=>"XML::Pastor::Schema::Object")) {
+		# If this is the first enumeration. Create the array. 
+		unless (defined($host->documentation())) {
+			$host->documentation(Data::HashArray->new());
+		}
+		
+		# Create the nex documentation
+		my $doc = XML::Pastor::Schema::Documentation->new();
+		$doc->setFields($attribs);
+		$doc->text($node->textContent());
+		
+		my $docs = $host->documentation;
+		push @$docs, $doc;		
+	}else {
+		# What is an 'documentation' doing outside the scope of a 'Schema::Object'?
+		die "Pastor : Documentation found where unexpected!\n" . _sprint_xml_element($node->parentNode() || $node) . "\n";;	
+	}
+	
+	# Nothing will get pushed on the node-stack.	
+	return undef;
+}
+
 #------------------------------------------------------------
 # This routine is called whenever an 'enumeration' element is encountered 
 # in the schema being processed.
@@ -521,6 +566,7 @@ sub _processEnumeration {
 }
 
 
+
 #------------------------------------------------------------
 # This routine is called whenever an 'extension' element is encountered 
 # in the schema being processed.
@@ -562,7 +608,7 @@ sub _processUnion {
 	my $obj	 	= XML::Pastor::Schema::Union->new()->setFields(getAttributeHash($node));
 
 	if (my $host=$context->findNode(class=>["XML::Pastor::Schema::SimpleType"])) {
-		$host->base("Union");
+		$host->base("Union|http://www.w3.org/2001/XMLSchema");
 		$host->derivedBy("union");		
 	}else {
 		die "Pastor : 'union' found where unexpected!\n" . _sprint_xml_element($node->parentNode()) . "\n";	
@@ -602,7 +648,7 @@ sub _processList {
 	my $obj	 	= XML::Pastor::Schema::List->new()->setFields(getAttributeHash($node));
 
 	if (my $host=$context->findNode(class=>["XML::Pastor::Schema::SimpleType"])) {
-		$host->base("List");
+		$host->base("List|http://www.w3.org/2001/XMLSchema");
 		$host->derivedBy("list");				
 	}else {
 		die "Pastor : 'list' found where unexpected!\n" . _sprint_xml_element($node->parentNode()) . "\n";	
@@ -735,10 +781,55 @@ sub _processSchemaNode {
 		die "Pastor : Schema elements cannot be nested!\n";
 	}
 	
-	$context->targetNamespace($obj->targetNamespace) if ($obj->targetNamespace);
+	my $nsUri = undef;
+	if ($obj->targetNamespace) {
+		# Schema defines a targetNamspace. It's easy.
+		$nsUri = $obj->targetNamespace();
+	}else{
+		# This schema doesn't define a targetNamespace itself. It probably means its included. 
+		# But perhaps we can get it from the previous schema.
+		my $cstack= $self->contextStack;
+		if ($cstack->count > 1) {
+			# Lucky, we've got one.
+			my $prevContext = $cstack->[1];	# This is the one before the top. Becuase a push is actually unshift.
+			$nsUri = $prevContext->targetNamespace();
+		}else {
+			# Hmmm. This is a truely no-namespace schema.
+			$nsUri = "";
+		}
+		
+	}
+
+	$context->targetNamespace($nsUri);	
+	$self->model->addNamespaceUri($nsUri);
+	
 	return $obj;
 }
 
+
+#------------------------------------------------------------
+# This routine is called whenever an 'simpleType' element is encountered 
+# in the schema being processed.
+#------------------------------------------------------------
+sub _processSimpleContent {
+	my $self 	= shift;
+	my $node 	= shift;	
+	my $context = $self->context();				
+	
+	# if this is a local definition, then our host element/attribute must be of this type
+	if (my $host=$context->findNode(class=>["XML::Pastor::Schema::ComplexType", 
+											])) {
+		$host->setFields({isSimpleContent=>1});
+	}
+
+	# Nothing to add to the model.
+
+	# Nothing will get pushed on the node-stack.
+	return undef;
+
+}
+
+
 #------------------------------------------------------------
 # This routine is called whenever an 'simpleType' element is encountered 
 # in the schema being processed.
@@ -765,7 +856,7 @@ sub _processSimpleType {
 											"XML::Pastor::Schema::List", 											
 											])) {
 		if ( 	UNIVERSAL::isa($host, "XML::Pastor::Schema::Attribute") ||
-     			UNIVERSAL::isa($host, "XML::Pastor::Schema::Attribute") ) {			
+     			UNIVERSAL::isa($host, "XML::Pastor::Schema::Element") ) {			
 			$host->setFields({type=>$obj->name()});
      	}elsif (UNIVERSAL::isa($host, "XML::Pastor::Schema::Union")) {
 			my $mbt=$host->memberTypes;
@@ -934,7 +1025,7 @@ sub _fixUpObject {
 		$obj->targetNamespace($context->targetNamespace) if ($context->targetNamespace);
 	}	
 	
-	$self->_fixNameSpaces($obj, $node, 'name');
+	$self->_fixNameSpaces($obj, $node, ['name'], localize => 1); 
 	return $obj;
 }
 
@@ -951,17 +1042,38 @@ sub _fixNameSpaces {
 	my $self	= shift;
 	my $obj		= shift;
 	my $node	= shift;
-	my $fields	= [@_];
+	my $fields	= shift;
+	my $opts	= {@_};
+	my $localize= $opts->{localize} || 0;
 	my $context	= $self->context();
+	my $verbose	= 0;
 	
 	foreach my $field (@$fields) {
 		my $uri = undef;
 		my $v	=$obj->{$field};
-		if ($v && ($v =~ /:/o)) {
+		print STDERR "Fixing up namespaces for '$field' ('$v')...\n" if ($verbose >=9);	
+		
+		if ($v && ($v =~ /\|/)) {
+			# Do nothing. There is already a namespace in there.
+		}elsif ($v && ($v =~ /:/o)) {
+			# There is a namesapce prefix in there.
 			my ($prefix, $local) = split /:/, $v, 2;
 			$uri = $node->lookupNamespaceURI($prefix);
-			$obj->{$field} = "$local|$uri" if ($uri);
-		}		
+			if ($uri) {
+				if ($localize) {
+					$obj->{$field} = $local;
+					$obj->{targetNamespace} = $uri;
+				}else {
+					$obj->{$field} = "$local|$uri";
+				}
+			}
+		}elsif ($v) {
+			if ($localize) {
+				$obj->{targetNamespace} = $context->targetNamespace();
+			}elsif (my $uri = $context->targetNamespace()) { 
+				$obj->{$field} = "$v|$uri";
+			}
+		}	
 	}
 	return $obj;
 }	
@@ -1090,7 +1202,7 @@ Note that there may be other bugs or limitations that the author is not aware of
 
 =head1 AUTHOR
 
-Ayhan Ulusoy <dev@ulusoy.name>
+Ayhan Ulusoy <dev(at)ulusoy(dot)name>
 
 
 =head1 COPYRIGHT
